Average Ability Levels for Multiple Class Mixed Rasch Model: Average Ability Levels for Multiple Class Mixed Rasch Model
Description
This function produces mean ability levels for each class in a mixture Rasch model.
Usage
avg.theta(x)
Arguments
x
A fitted multiple class mixture Rasch model
Details
mixRaschTools Average Theta -----------------------------------------------------------
This function produces a matrix containing the average theta values for each latent class
included in mixture Rasch model.
References
Willse, J. T. (2011). Mixture Rasch models with joint maximum likelihood estimation. Educational and Psychological Measurement, 71, 5-19, https://doi.org/10.1177/0013164410387335
# NOT RUN {##Example multiple class mixture Rasch models included with mixRaschToolkitdata(threeclass_ex)
##Average Theta Valuesavg.theta(threeclass_ex)
# }