This function provides an item parameter plot that can be used to compare the different item
parameters in mixture Rasch models that contain two or more latent classes.
# NOT RUN {##Example multiple class mixture Rasch models included with mixRaschToolsdata(threeclass_ex)
##Item Parameter PlotmixRasch.plot(threeclass_ex)
# }